@@ -41,8 +41,8 @@ my $empty_port;
 my $server;
 my $redis;
 my $max_size                = 512 * 1024 * 1024;    # 512MB
-my $advance_cleanup_bytes   = 0;
-my $advance_cleanup_num     = 0;
+my $min_cleanup_bytes       = 0;
+my $min_cleanup_items       = 0;
 my $max_lists               = 2_000_000;
 my $data_len                = 200;
 my $run_time                = 0;
@@ -66,8 +66,8 @@ my $ret = GetOptions(
     'port=i'                    => \$port,
     'coll_name=s'               => \$coll_name,
     'max_size=i'                => \$max_size,
-    'advance_cleanup_bytes=i'   => \$advance_cleanup_bytes,
-    'advance_cleanup_num=i'     => \$advance_cleanup_num,
+    'min_cleanup_bytes=i'       => \$min_cleanup_bytes,
+    'min_cleanup_items=i'       => \$min_cleanup_items,
     'data_len=i'                => \$data_len,
     'visitors=i'                => \$max_lists,
     'run_time=i'                => \$run_time,
@@ -80,7 +80,7 @@ my $ret = GetOptions(
 if ( !$ret || $help )
 {
     print <<'HELP';
-Usage: $0 [--host="..."] [--port=...] [--coll_name="..."] [--max_size=...] [--advance_cleanup_bytes=...] [--advance_cleanup_num=...] [--data_len=...] [--visitors=...] [--run_time=...] [--rate=...] [--dump=...] [--receive] [--help]
+Usage: $0 [--host="..."] [--port=...] [--coll_name="..."] [--max_size=...] [--min_cleanup_bytes=...] [--min_cleanup_items=...] [--data_len=...] [--visitors=...] [--run_time=...] [--rate=...] [--dump=...] [--receive] [--help]
 
 Start a Redis client, connect to the Redis server, randomly inserts or receives data
 
@@ -90,39 +90,39 @@ Options:
 
     --host="..."
         The server should contain an IP address of Redis server.
-        If the server is not provided, '127.0.0.1' is used as the default for the Redis server.
+        If not provided, '127.0.0.1' is used as the default.
     --port=N
         The server port.
-        Default 6379 (the default for the Redis server).
+        Default 6379 (the default for Redis server).
     --coll_name="..."
-        The collection name.
-        Default = pid.
-        Be used together with '--receive'.
+        Collection name.
+        Default = process pid.
+        To be used along with '--receive' option.
     --max_size=N
-        The maximum size, in bytes, of the capped collection data.
+        The maximum size (bytes) of capped collection data volume.
         Default 512MB.
-    --advance_cleanup_bytes=N
-        The minimum size, in bytes, of the data to be released, if the size of the collection data after adding new data may exceed 'max_size'.
-        Default 0 - additional data should not be released.
-    --advance_cleanup_num=N
-        The amount of data that must be removed, if the size of the collection data after adding new data may exceed 'max_size'.
-        Default 0 - additional data should not be released.
+    --min_cleanup_bytes=N
+        Size (bytes) of the data to be freed should size of the collection exceed 'max_size'.
+        Default 0 - no advance cleanup performed.
+    --min_cleanup_items=N
+        Number of elements to be removed from collection during advance cleanup.
+        Default 0 - no advance cleanup performed.
     --data_len=...
-        Length of the unit recording data.
-        Default 200 byte.
+        Data unit size.
+        Default 200 bytes.
     --visitors=N
-        The number of visitors (data lists) that must be created.
+        The number of lists to be created.
         Default 2_000_000.
     --run_time=...
-        Maximum, in seconds, run time.
-        Default 0 - the work is not limited.
+        Maximum run time in seconds
+        Default 0 - unlimited.
     --rate=N
-        Exponentially distributed data with RATE.
-        Default 0 - no exponentially data distributed.
+        Exponentially distribute data using provided RATE.
+        Default 0 - no exponental distribution.
     --dump=N
-        Amount of data for which to perform dump.
-        Default 0 - does not perform.
-        WARNING: Before work removes all keys from the current database.
+        Data dump volume.
+        Default 0 - do not perform dump.
+        WARNING: removes all keys from the current database.
     --receive
         Receive data instead of writing.
 HELP
@@ -163,8 +163,8 @@ sub client_info {
         "maxmemory-policy       ", ( $redis->config_get( 'maxmemory-policy' ) )[1], "\n",
         "maxmemory              ", ( $redis->config_get( 'maxmemory' ) )[1],        "\n",
         "max_size               $max_size",                     "\n",
-        "advance_cleanup_bytes  $advance_cleanup_bytes",        "\n",
-        "advance_cleanup_num    $advance_cleanup_num",          "\n",
+        "min_cleanup_bytes      $min_cleanup_bytes",            "\n",
+        "min_cleanup_items      $min_cleanup_items",              "\n",
         "max_lists              $max_lists",                    "\n",
         "rate                   $rate",                         "\n",
         "dump                   $dump",                         "\n",
@@ -303,8 +303,8 @@ $coll = Redis::CappedCollection->create(
     redis   => $redis,
     name    => $coll_name,
     $receive ? () : (
-        advance_cleanup_bytes   => $advance_cleanup_bytes,
-        advance_cleanup_num     => $advance_cleanup_num,
+        min_cleanup_bytes   => $min_cleanup_bytes,
+        min_cleanup_items   => $min_cleanup_items,
     ),
 );
 
